import { Chain, Network, amount as sdkAmount } from "@wormhole-foundation/sdk-base";
import { SignedQuote } from "@wormhole-foundation/sdk-definitions";
export declare enum RelayStatus {
    Pending = "pending",
    Failed = "failed",
    Unsupported = "unsupported",
    Submitted = "submitted",
    Underpaid = "underpaid",
    Aborted = "aborted"
}
export type RequestForExecution = {
    quoterAddress: `0x${string}`;
    amtPaid: string;
    dstChain: number;
    dstAddr: `0x${string}`;
    refundAddr: `0x${string}`;
    signedQuoteBytes: `0x${string}`;
    requestBytes: `0x${string}`;
    relayInstructionsBytes: `0x${string}`;
    timestamp: Date;
};
export type TxInfo = {
    txHash: string;
    chainId: number;
    blockNumber: string;
    blockTime: Date | null;
    cost: string;
};
export type RelayData = {
    id: `0x${string}`;
    txHash: string;
    chainId: number;
    status: string;
    estimatedCost: string;
    requestForExecution: RequestForExecution;
    instruction?: Request;
    txs?: TxInfo[];
    indexed_at: Date;
};
export declare enum RequestPrefix {
    ERM1 = "ERM1",// MM
    ERV1 = "ERV1",// VAA_V1
    ERN1 = "ERN1",// NTT_V1
    ERC1 = "ERC1",// CCTP_V1
    ERC2 = "ERC2"
}
export type Capabilities = {
    requestPrefixes: Array<keyof typeof RequestPrefix>;
    gasDropOffLimit: string;
    maxGasLimit: string;
    maxMsgValue: string;
};
export interface CapabilitiesResponse {
    [chainId: string]: Capabilities;
}
export declare function fetchCapabilities(network: Network): Promise<CapabilitiesResponse>;
export interface QuoteResponse {
    signedQuote: `0x${string}`;
    estimatedCost?: string;
}
export declare function fetchSignedQuote(network: Network, srcChain: Chain, dstChain: Chain, relayInstructions: string): Promise<QuoteResponse>;
export interface StatusResponse extends RelayData {
    signedQuote: SignedQuote;
    estimatedCost: string;
}
export declare function fetchStatus(network: Network, txHash: string, chain: Chain): Promise<StatusResponse[]>;
export declare function calculateReferrerFee(_amount: sdkAmount.Amount, dBps: bigint, destinationTokenDecimals: number): {
    referrerFee: bigint;
    remainingAmount: bigint;
    referrerFeeDbps: bigint;
};
//# sourceMappingURL=utils.d.ts.map