import { toChainId, amount as sdkAmount, } from "@wormhole-foundation/sdk-base";
import axios from "axios";
import { apiBaseUrl } from "./consts.js";
import { NttRoute } from "../types.js";
export var RelayStatus;
(function (RelayStatus) {
    RelayStatus["Pending"] = "pending";
    RelayStatus["Failed"] = "failed";
    RelayStatus["Unsupported"] = "unsupported";
    RelayStatus["Submitted"] = "submitted";
    RelayStatus["Underpaid"] = "underpaid";
    RelayStatus["Aborted"] = "aborted";
})(RelayStatus || (RelayStatus = {}));
export var RequestPrefix;
(function (RequestPrefix) {
    RequestPrefix["ERM1"] = "ERM1";
    RequestPrefix["ERV1"] = "ERV1";
    RequestPrefix["ERN1"] = "ERN1";
    RequestPrefix["ERC1"] = "ERC1";
    RequestPrefix["ERC2"] = "ERC2";
})(RequestPrefix || (RequestPrefix = {}));
export async function fetchCapabilities(network) {
    const url = `${apiBaseUrl[network]}/v0/capabilities`;
    try {
        const response = await axios.get(url);
        return response.data;
    }
    catch (error) {
        throw new Error(`Failed to fetch capabilities for network: ${network}.`);
    }
}
export async function fetchSignedQuote(network, srcChain, dstChain, relayInstructions // TODO: `0x:${string}`
) {
    const url = `${apiBaseUrl[network]}/v0/quote`;
    try {
        const response = await axios.post(url, {
            srcChain: toChainId(srcChain),
            dstChain: toChainId(dstChain),
            relayInstructions,
        });
        return response.data;
    }
    catch (error) {
        throw new Error(`Failed to fetch signed quote.`);
    }
}
// Fetch Status
export async function fetchStatus(network, txHash, chain) {
    const url = `${apiBaseUrl[network]}/v0/status/tx`;
    try {
        const response = await axios.post(url, {
            txHash,
            chainId: toChainId(chain),
        });
        return response.data;
    }
    catch (error) {
        throw new Error(`Failed to fetch status for txHash: ${txHash}.`);
    }
}
const MAX_U16 = 65535n;
export function calculateReferrerFee(_amount, dBps, destinationTokenDecimals) {
    if (dBps > MAX_U16) {
        throw new Error("dBps exceeds max u16");
    }
    const amount = sdkAmount.units(_amount);
    let remainingAmount = amount;
    let referrerFee = 0n;
    if (dBps > 0) {
        referrerFee = (amount * dBps) / 100000n;
        // The NttManagerWithExecutor trims the fee before subtracting it from the amount
        const trimmedFee = NttRoute.trimAmount(sdkAmount.fromBaseUnits(referrerFee, _amount.decimals), destinationTokenDecimals);
        remainingAmount = amount - sdkAmount.units(trimmedFee);
    }
    return { referrerFee, remainingAmount, referrerFeeDbps: dBps };
}
//# sourceMappingURL=utils.js.map